==> qtjambi-help-6.2.8-sources.jar: io/qt/help/QHelpIndexWidget.java <==
package io.qt.help;


/**
 * <p>List view displaying the QHelpIndexModel</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qhelpindexwidget.html">QHelpIndexWidget</a></p>
 */
public final class QHelpIndexWidget extends io.qt.widgets.QListView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpIndexWidget.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentActivated">QHelpIndexWidget::documentActivated(QHelpLink,QString)</a></p>
     */
    public final Signal2<io.qt.help.QHelpLink, java.lang.String> documentActivated = new Signal2<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentsActivated">QHelpIndexWidget::documentsActivated(QList&lt;QHelpLink&gt;,QString)</a></p>
     */
    public final Signal2<java.util.List<io.qt.help.QHelpLink>, java.lang.String> documentsActivated = new Signal2<>();

    /**
     * @deprecated Use documentActivated() instead
     */
    @Deprecated
    public final Signal2<io.qt.core.QUrl, java.lang.String> linkActivated = new Signal2<>();

    /**
     * @deprecated Use documentsActivated() instead
     */
    @Deprecated
    public final Signal2<java.util.NavigableMap<java.lang.String, ? extends java.util.List<io.qt.core.QUrl>>, java.lang.String> linksActivated = new Signal2<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#activateCurrentItem">QHelpIndexWidget::activateCurrentItem()</a></p>
     */
    public final void activateCurrentItem(){
        activateCurrentItem_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void activateCurrentItem_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #filterIndices(java.lang.String, java.lang.String)}
     *  with <code>wildcard = (String)null</code>.</p>
     */
    public final void filterIndices(java.lang.String filter) {
        filterIndices(filter, (String)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#filterIndices">QHelpIndexWidget::filterIndices(QString,QString)</a></p>
     */
    public final void filterIndices(java.lang.String filter, java.lang.String wildcard){
        filterIndices_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), filter, wildcard);
    }
    
    private native void filterIndices_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String filter, java.lang.String wildcard);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpIndexWidget(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.3.1-sources.jar: io/qt/help/QHelpIndexWidget.java <==
package io.qt.help;


/**
 * <p>List view displaying the QHelpIndexModel</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpindexwidget.html">QHelpIndexWidget</a></p>
 */
public final class QHelpIndexWidget extends io.qt.widgets.QListView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpIndexWidget.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentActivated">QHelpIndexWidget::documentActivated(QHelpLink,QString)</a></p>
     */
    public final Signal2<io.qt.help.QHelpLink, java.lang.String> documentActivated = new Signal2<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#documentsActivated">QHelpIndexWidget::documentsActivated(QList&lt;QHelpLink&gt;,QString)</a></p>
     */
    public final Signal2<java.util.List<io.qt.help.QHelpLink>, java.lang.String> documentsActivated = new Signal2<>();

    /**
     * @deprecated Use documentActivated() instead
     */
    @Deprecated
    public final Signal2<io.qt.core.QUrl, java.lang.String> linkActivated = new Signal2<>();

    /**
     * @deprecated Use documentsActivated() instead
     */
    @Deprecated
    public final Signal2<java.util.NavigableMap<java.lang.String, java.util.List<io.qt.core.QUrl>>, java.lang.String> linksActivated = new Signal2<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#activateCurrentItem">QHelpIndexWidget::activateCurrentItem()</a></p>
     */
    public final void activateCurrentItem(){
        activateCurrentItem_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void activateCurrentItem_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #filterIndices(java.lang.String, java.lang.String)}
     *  with <code>wildcard = ""</code>.</p>
     */
    public final void filterIndices(java.lang.String filter) {
        filterIndices(filter, "");
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexwidget.html#filterIndices">QHelpIndexWidget::filterIndices(QString,QString)</a></p>
     */
    public final void filterIndices(java.lang.String filter, java.lang.String wildcard){
        filterIndices_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), filter, wildcard);
    }
    
    private native void filterIndices_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String filter, java.lang.String wildcard);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpIndexWidget(QPrivateConstructor p) { super(p); } 
    
}
